LayerManager
============

.. currentmodule:: pywwt.layers

.. autoclass:: LayerManager
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~LayerManager.add_data_layer
      ~LayerManager.add_hips_catalog_layer
      ~LayerManager.add_image_layer
      ~LayerManager.add_preloaded_image_layer
      ~LayerManager.add_table_layer
      ~LayerManager.remove_layer

   .. rubric:: Methods Documentation

   .. automethod:: add_data_layer
   .. automethod:: add_hips_catalog_layer
   .. automethod:: add_image_layer
   .. automethod:: add_preloaded_image_layer
   .. automethod:: add_table_layer
   .. automethod:: remove_layer
